@@ -25,10 +25,13 @@
 #include <gnome.h>
 #include <gtk/gtk.h>
 #include <libgnomeui/gnome-icon-theme.h>
+#include <libsoup/soup.h>
 
 void e_webcal_display_error (const gchar * title, const gchar * message,
-				GtkWidget * parent);
+			     GtkWidget * parent);
+
 void e_webcal_query_user (const gchar * name, const gchar * desc,
-			     const gchar * caluri);
+                          const gchar * caluri,
+                          gboolean has_event, gboolean has_todo);
 
 #endif
